@@ -38,7 +38,7 @@
  *
  * Since: 17.0.0
  */
-#define GPARQUET_VERSION_MAJOR (22)
+#define GPARQUET_VERSION_MAJOR (23)
 
 /**
  * GPARQUET_VERSION_MINOR:
@@ -110,6 +110,15 @@
 #  define GPARQUET_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GPARQUET_VERSION_23_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 23.0.0
+ */
+#define GPARQUET_VERSION_23_0 G_ENCODE_VERSION(23, 0)
+
 /**
  * GPARQUET_VERSION_22_0:
  *
@@ -440,6 +449,20 @@
 
 #define GPARQUET_AVAILABLE_IN_ALL GPARQUET_EXTERN
 
+#if GPARQUET_VERSION_MIN_REQUIRED >= GPARQUET_VERSION_23_0
+#  define GPARQUET_DEPRECATED_IN_23_0               GPARQUET_DEPRECATED
+#  define GPARQUET_DEPRECATED_IN_23_0_FOR(function) GPARQUET_DEPRECATED_FOR(function)
+#else
+#  define GPARQUET_DEPRECATED_IN_23_0
+#  define GPARQUET_DEPRECATED_IN_23_0_FOR(function)
+#endif
+
+#if GPARQUET_VERSION_MAX_ALLOWED < GPARQUET_VERSION_23_0
+#  define GPARQUET_AVAILABLE_IN_23_0 GPARQUET_EXTERN GPARQUET_UNAVAILABLE(23, 0)
+#else
+#  define GPARQUET_AVAILABLE_IN_23_0 GPARQUET_EXTERN
+#endif
+
 #if GPARQUET_VERSION_MIN_REQUIRED >= GPARQUET_VERSION_22_0
 #  define GPARQUET_DEPRECATED_IN_22_0               GPARQUET_DEPRECATED
 #  define GPARQUET_DEPRECATED_IN_22_0_FOR(function) GPARQUET_DEPRECATED_FOR(function)
